##- Nanar <nanardon@mandrake.org>
##-
##- This program is free software; you can redistribute it and/or modify
##- it under the terms of the GNU General Public License as published by
##- the Free Software Foundation; either version 2, or (at your option)
##- any later version.
##-
##- This program is distributed in the hope that it will be useful,
##- but WITHOUT ANY WARRANTY; without even the implied warranty of
##- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##- GNU General Public License for more details.
##-
##- You should have received a copy of the GNU General Public License
##- along with this program; if not, write to the Free Software
##- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# $Id: Spec.pm,v 1.5 2005/03/08 04:18:27 othauvin Exp $

package Hdlist::Spec;

use strict;
use warnings;

use Hdlist;

sub rpmbuild {
    my ($spec, $flags, %options) = @_;

    $options{db} ||= Hdlist::newdb();

    my ($f) = $flags =~ /^(?:-)?b([pcibas])/;
    $f or die "Unknown build options '$flags', should be b[pciabs]\n";
    my @buildflags;
    for (qw/p c i/) {
        $options{shortcircuit} && $f ne $_ and next;
        /^p$/ and push (@buildflags, "PREP");
        /^c$/ and push (@buildflags, "BUILD");
        /^l$/ and push (@buildflags, "FILECHECK");
        /^i$/ and push (@buildflags, qw/INSTALL CHECK/);
        $f eq $_ and last;
    }
    for ($f) {
        /^a$/ and push(@buildflags, qw/PACKAGESOURCE PACKAGEBINARY/);
        /^b$/ and push(@buildflags, qw/PACKAGEBINARY/);
        /^s$/ and push(@buildflags, qw/PACKAGESOURCE/);
    }
    $options{clean} and push(@buildflags, qw/RMBUILD RMSOURCE/);
    $options{rmspec} and push(@buildflags, qw/RMSPEC/);


    if (!$options{nodeps}) {
        my $sh = $spec->srcheader() or die "Can't get source header from spec object"; # Can't happend
        $options{db}->transadd($sh, "", 0);
        $options{db}->transcheck;
        my @pb = $options{db}->transpb();
        $options{db}->transreset();
        if (@pb) {
            Hdlist::rpmlog("ERR", "$_\n") foreach(Hdlist::format_rpmpb(@pb));
            return 1;
        }
    }
    return $options{db}->specbuild($spec, [ @buildflags ]);
}

1;

__END__

=head1 NAME

Hdlist::Spec

=head1 SYNOPSIS

=head1 DESCRIPTION

Extend method availlable on Hdlist::Spec objects

=head1 METHODS

=head2 Hdlist::Spec->srcheader()

Returns a Hdlist::Header object like source rpm will be.
Please notice that the header is not finish and header information you'll
get can be incomplete, it depend if you call the function before or after
Hdlist::Spec->build().

=head2 Hdlist::Spec->srcrpm()

Returns the source filename spec file will build. The function take care
about rpmlib configuration (build dir path).

=head2 Hdlist::Spec->binrpm()

Returns files names of binaries rpms that spec will build. The function take
care about rpmlib configuration (build dir path).

=head2 Hdlist::Spec->build([ @actions ])

Run build process on spec file.
Each value in @actions is one or more actions to do:

  - PACKAGESOURCE: build source package,
  - PREP: run prep stage,
  - BUILD: run build stage,
  - INSTALL: run install stage,
  - CHECK: check installed files,
  - FILECHECK: check installed files,
  - PACKAGEBINARY: build binaries packages,
  - CLEAN: run clean stage,
  - RMSPEC: delete spec file,
  - RMSOURCE: delete sources files,
  - RMBUILD: delete build files,

=head2 rpmbuild($flags, %options)

Build a spec using rpm same rpm options.

$flags should be -b[abspci]

%options is a list of optionnal options:

=over 4

=item db 

reuse an already existing Hdlist::Db object (else a new one is created)

=item clean

if set, clean source and build tre (like rpmbuild --clean

=item rmspec

if set, delete the spec after build (like rpmbuild --rmspec)

=item nodeps

If set, don't check dependancies before build

=item shortcircuit

if set, run only the build stage asked, not all preceding (like rpmbuild
--short-circuit)

=back

=head1 SEE ALSO

L<Hdlist>

=cut
